/* UTIL.C - Utility procedures for base method programs. */

#include <stdio.h>


/* COUNT LINES IN FILE.  Reads the given file, ignoring all the data
   except to count how many lines there are.  Excess characters after
   the last newline are not considered to be a line. */

int count_lines
( FILE *f	/* File to count lines in */
)
{  
  int c, count;

  count = 0;

  for (;;)
  { c = getc(f);
    if (c==EOF) return count;
    if (c=='\n') count += 1;
  }
}


/* READ LAST ITEM ON A LINE.  Reads the next line of input from the
   given file, separates out the last whitespace-delimited item on that 
   line, and stores it in the space provided.  Returns one of the following:

      EOF  EOF or error encountered
       0   everything OK
       1   there is no item on the line (empty of all but whitespace)
       2   the item is too large 

   Excess characters after the last newline are not considered to be a
   line. */

int read_last_item
( FILE *f,	/* File to read from */
  char *item,	/* Place to store item */
  int max_item  /* Maximum size of item */
)
{
  int i, c, w;
  
  i = 0;
  w = 1;

  for (;;)
  { 
    c = getc(f);

    switch (c)
    { case EOF:  
      { return EOF;
      }
      case '\n': 
      { if (i>max_item) return 2;
        if (i==0) return 1;
        item[i] = 0;
        return 0;  
      }
      case ' ': case '\t':
      { w = 1;
        break;
      }
      default:
      { if (w==1) { i = 0; w = 0; }
        if (i<max_item) item[i] = c;
        i += 1;
        break;
      }
    }
  }
}
